==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/backend/mail/api/MessageBody.cs <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;

namespace net.bluemind.backend.mail.api
{
  [DataContract(Namespace="")]
  public partial class MessageBody  {
    [DataMember]
    public String guid;
    
    [DataMember]
    public String subject;
    
    [DataMember]
    public Boolean smartAttach;
    
    [IgnoreDataMember]
    public System.DateTime? date;
    [DataMember(Name = "date")]
    public String dateSurrogate
    {
      get
      {
        return (date != null)
          ? "" + Math.Floor((((DateTime)date) -
           new DateTime(1970, 1, 1, 0, 0, 0, 0, DateTimeKind.Utc)).TotalMilliseconds)
          : null;
      }
      set
      {
        try
        {
          var time0 = new DateTime(1970, 1, 1, 0, 0, 0, 0, DateTimeKind.Utc);
          date = !String.IsNullOrEmpty(value)
            ? time0.AddMilliseconds(double.Parse(value)).ToLocalTime()
            : (DateTime?) null;
        }
        catch (Exception)
        {
          date = null;
        }
      }
    }
    
    [DataMember]
    public int? size;
    
    [DataMember]
    public List<net.bluemind.backend.mail.api.MessageBodyHeader> headers = new List<net.bluemind.backend.mail.api.MessageBodyHeader>();
    
    [DataMember]
    public List<net.bluemind.backend.mail.api.MessageBodyRecipient> recipients = new List<net.bluemind.backend.mail.api.MessageBodyRecipient>();
    
    [DataMember]
    public String messageId;
    
    [DataMember]
    public List<String> references = new List<String>();
    
    [DataMember]
    public net.bluemind.backend.mail.api.MessageBodyPart structure = new net.bluemind.backend.mail.api.MessageBodyPart();
    
    [DataMember]
    public String preview;
    
    [DataMember]
    public int? bodyVersion;
    
  
  }
}

==> net.bluemind.p2.platform-5.4.2760.zip: net/bluemind/backend/mail/api/MessageBody.cs <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Serialization;

namespace net.bluemind.backend.mail.api
{
  [DataContract(Namespace="")]
  public partial class MessageBody  {
    [DataMember]
    public String guid;
    
    [DataMember]
    public String subject;
    
    [DataMember]
    public Boolean smartAttach;
    
    [IgnoreDataMember]
    public System.DateTime? date;
    [DataMember(Name = "date")]
    public String dateSurrogate
    {
      get
      {
        return (date != null)
          ? "" + Math.Floor((((DateTime)date) -
           new DateTime(1970, 1, 1, 0, 0, 0, 0, DateTimeKind.Utc)).TotalMilliseconds)
          : null;
      }
      set
      {
        try
        {
          var time0 = new DateTime(1970, 1, 1, 0, 0, 0, 0, DateTimeKind.Utc);
          date = !String.IsNullOrEmpty(value)
            ? time0.AddMilliseconds(double.Parse(value)).ToLocalTime()
            : (DateTime?) null;
        }
        catch (Exception)
        {
          date = null;
        }
      }
    }
    
    [IgnoreDataMember]
    public System.DateTime? created;
    [DataMember(Name = "created")]
    public String createdSurrogate
    {
      get
      {
        return (created != null)
          ? "" + Math.Floor((((DateTime)created) -
           new DateTime(1970, 1, 1, 0, 0, 0, 0, DateTimeKind.Utc)).TotalMilliseconds)
          : null;
      }
      set
      {
        try
        {
          var time0 = new DateTime(1970, 1, 1, 0, 0, 0, 0, DateTimeKind.Utc);
          created = !String.IsNullOrEmpty(value)
            ? time0.AddMilliseconds(double.Parse(value)).ToLocalTime()
            : (DateTime?) null;
        }
        catch (Exception)
        {
          created = null;
        }
      }
    }
    
    [DataMember]
    public int? size;
    
    [DataMember]
    public List<net.bluemind.backend.mail.api.MessageBodyHeader> headers = new List<net.bluemind.backend.mail.api.MessageBodyHeader>();
    
    [DataMember]
    public List<net.bluemind.backend.mail.api.MessageBodyRecipient> recipients = new List<net.bluemind.backend.mail.api.MessageBodyRecipient>();
    
    [DataMember]
    public String messageId;
    
    [DataMember]
    public List<String> references = new List<String>();
    
    [DataMember]
    public net.bluemind.backend.mail.api.MessageBodyPart structure = new net.bluemind.backend.mail.api.MessageBodyPart();
    
    [DataMember]
    public String preview;
    
    [DataMember]
    public int? bodyVersion;
    
  
  }
}
